@@ -35,6 +35,7 @@ BinaryClockWidget::BinaryClockWidget(QWidget *parent) :
     layout->addWidget(secondsWidget);
 
     setFixedSize(sizeHint());
+    layout->setSizeConstraint(QLayout::SetMinimumSize);
 
     updateTime();
 
@@ -55,16 +56,16 @@ BinaryClockWidget::~BinaryClockWidget(){
     delete layout;
 }
 
-void BinaryClockWidget::setBaseSize(int size){
-    secondsWidget->setBaseSize(size);
-    minutesWidget->setBaseSize(size);
-    hoursWidget->setBaseSize(size);
+void BinaryClockWidget::setLedSize(int size){
+    secondsWidget->setLedSize(size);
+    minutesWidget->setLedSize(size);
+    hoursWidget->setLedSize(size);
 }
 
-void BinaryClockWidget::setBorder(int border){
-    secondsWidget->setBorder(border);
-    minutesWidget->setBorder(border);
-    hoursWidget->setBorder(border);
+void BinaryClockWidget::setLedBorder(int border){
+    secondsWidget->setLedBorder(border);
+    minutesWidget->setLedBorder(border);
+    hoursWidget->setLedBorder(border);
 }
 
 void BinaryClockWidget::setLedColor(const QColor &color){
@@ -74,8 +75,12 @@ void BinaryClockWidget::setLedColor(const QColor &color){
 }
 
 QSize BinaryClockWidget::sizeHint(){
-    return QSize((6 * (secondsWidget->getBaseSize())) + (2 * layout->margin()) + 35,
-                 (3 * secondsWidget->getBaseSize()) + (2 * layout->margin()) + 6);
+    return QSize((6 * (secondsWidget->getElementSize())) + (2 * layout->margin())
+#ifdef Q_WS_MAEMO_5
+                 + 35
+#endif
+                 ,
+                 (3 * secondsWidget->getElementSize()) + (2 * layout->margin()) + 6);
 }
 
 void BinaryClockWidget::updateTime(){
