@@ -21,28 +21,23 @@
 #define CLOCKWIDGET_H
 
 #include <QColor>
-#include <QMouseEvent>
 #include <QSize>
 #include <QWidget>
 
+#include <QMouseEvent>
+
 class ClockWidget : public QWidget
 {
     Q_OBJECT
+
 public:
     explicit ClockWidget(QWidget *parent = 0);
 
-    virtual void setBaseSize(int size) = 0;
-    virtual void setBorder(int border) = 0;
+    virtual void setLedSize(int size) = 0;
+    virtual void setLedBorder(int border) = 0;
     virtual void setLedColor(const QColor &color) = 0;
 
     virtual QSize sizeHint() = 0;
-
-signals:
-    void clicked();
-
-protected:
-    void mouseReleaseEvent(QMouseEvent *event);
-
 };
 
 #endif // CLOCKWIDGET_H
