@@ -19,14 +19,14 @@
 
 #include "horizontalbinarydisplaywidget.h"
 
-HorizontalBinaryDisplayWidget::HorizontalBinaryDisplayWidget(int bits, int value, int height, QWidget *parent) :
-    BinaryDisplayWidget(bits, value, height, parent)
+HorizontalBinaryDisplayWidget::HorizontalBinaryDisplayWidget(int bits, int value, int widgetSize, QWidget *parent) :
+    BinaryDisplayWidget(bits, value, widgetSize, parent)
 {
 }
 
 void HorizontalBinaryDisplayWidget::draw(QPainter *painter){
     for(int i = 0; i < bits; i++){
-        drawLed(((height - bits) * baseSize) + (baseSize * i),
+        drawLed(((widgetSize - bits) * getElementSize()) + (getElementSize() * i),
                 0,
                 ((value & (1 << (bits - i - 1))) > 0),
                 painter);
@@ -34,6 +34,6 @@ void HorizontalBinaryDisplayWidget::draw(QPainter *painter){
 }
 
 QSize HorizontalBinaryDisplayWidget::sizeHint(){
-    return QSize(baseSize * height, baseSize);
+    return QSize(getElementSize() * widgetSize, getElementSize());
 }
 
