@@ -20,7 +20,12 @@
 #ifndef MAINWIDGET_H
 #define MAINWIDGET_H
 
+#ifndef Q_WS_MAEMO_5
+#include <QAction>
+#include <QMenu>
 #include <QMouseEvent>
+#endif
+
 #include <QPaintEvent>
 #include <QVBoxLayout>
 #include <QWidget>
@@ -38,23 +43,35 @@ public:
 public slots:
     void openSettingsDialog();
 
-signals:
-    void clicked();
-
 protected:
-    void mouseReleaseEvent(QMouseEvent *event);
     void paintEvent(QPaintEvent *event);
 
 private slots:
     void setClock(int clockStyle);
-    void switchClockStyle();
 
 private:
-    int currentClockStyle;
-
     ClockWidget *clockWidget;
 
     QVBoxLayout *layout;
+
+    void applySettings();
+
+#ifndef Q_WS_MAEMO_5
+protected:
+    void mouseMoveEvent(QMouseEvent *);
+    void mousePressEvent(QMouseEvent *event);
+
+private:
+    QPoint position;
+
+    QMenu *menu;
+    QAction *closeAction;
+    QAction *settingsAction;
+
+    bool transparency;
+
+    void createMenu();
+#endif
 };
 
 #endif // MAINWIDGET_H
