@@ -32,11 +32,28 @@ class SettingsDialog : public QDialog
 
 public:
     static const QString CLOCK_LED_COLOR;
-    static const QString CLOCK_STYLE;
-
     static const QColor CLOCK_LED_COLOR_DEFAULT;
+
+    static const QString CLOCK_STYLE;
     static const int CLOCK_STYLE_DEFAULT;
 
+    static const QString LED_BORDER;
+    static const int LED_BORDER_DEFAULT;
+
+    static const QString LED_SIZE;
+    static const int LED_SIZE_DEFAULT;
+
+#ifndef Q_WS_MAEMO_5
+    static const QString POSITION;
+    static const QPoint POSITION_DEFAULT;
+
+    static const QString TRANSPARENCY;
+    static const bool TRANSPARENCY_DEFAULT;
+
+    static const QString WIDGET_PLACEMENT;
+    static const int WIDGET_PLACEMENT_DEFAULT;
+#endif
+
 
     explicit SettingsDialog(QWidget *parent = 0);
     ~SettingsDialog();
